@@ -41,32 +41,43 @@
 
 VNoteMainManager::VNoteMainManager()
 {
+    qInfo() << "VNoteMainManager constructor called";
 }
 
 // 写一个单例模式的类
 VNoteMainManager *VNoteMainManager::instance()
 {
+    qInfo() << "VNoteMainManager instance requested";
     static VNoteMainManager instance;
     return &instance;
 }
 
 void VNoteMainManager::initNote()
 {
+    qInfo() << "Initializing note manager";
     m_richTextManager = new WebRichTextManager();
     initConnections();
     initData();
+
+    int savedAudioSource = loadAudioSource();
+    qInfo() << "Loading saved audio source setting:" << savedAudioSource;
+    VoiceRecoderHandler::instance()->changeMode(savedAudioSource);
+    qInfo() << "Note manager initialization finished";
 }
 
 void VNoteMainManager::initData()
 {
+    qInfo() << "Initializing data";
     VNoteDataManager::instance()->reqNoteDefIcons();
     VNoteDataManager::instance()->reqNoteFolders();
     QThread::msleep(200);
     VNoteDataManager::instance()->reqNoteItems();
+    qInfo() << "Data initialization finished";
 }
 
 void VNoteMainManager::initConnections()
 {
+    qInfo() << "Initializing connections";
     connect(VNoteDataManager::instance(), &VNoteDataManager::onAllDatasReady,
             this, &VNoteMainManager::onVNoteFoldersLoaded);
     connect(m_richTextManager, &WebRichTextManager::needUpdateNote, this, &VNoteMainManager::needUpdateNote);
@@ -75,10 +86,12 @@ void VNoteMainManager::initConnections()
     connect(m_richTextManager, &WebRichTextManager::scrollChange, this, &VNoteMainManager::scrollChange);
     connect(m_richTextManager, &WebRichTextManager::finishedUpdateNote, this, &VNoteMainManager::exitWithSave);
     connect(VoiceRecoderHandler::instance(), &VoiceRecoderHandler::finishedRecod, this, &VNoteMainManager::insertVoice);
+    qInfo() << "Connections initialized";
 }
 
 QObject *jsContent_provider(QQmlEngine *engine, QJSEngine *scriptEngine)
 {
+    qInfo() << "jsContent_provider called";
     Q_UNUSED(engine)
     Q_UNUSED(scriptEngine)
 
@@ -87,6 +100,7 @@ QObject *jsContent_provider(QQmlEngine *engine, QJSEngine *scriptEngine)
 
 QObject *mainManager_provider(QQmlEngine *engine, QJSEngine *scriptEngine)
 {
+    qInfo() << "mainManager_provider called";
     Q_UNUSED(engine)
     Q_UNUSED(scriptEngine)
 
@@ -95,6 +109,7 @@ QObject *mainManager_provider(QQmlEngine *engine, QJSEngine *scriptEngine)
 
 QObject *actionManager_provider(QQmlEngine *engine, QJSEngine *scriptEngine)
 {
+    qInfo() << "actionManager_provider called";
     Q_UNUSED(engine)
     Q_UNUSED(scriptEngine)
 
@@ -103,6 +118,7 @@ QObject *actionManager_provider(QQmlEngine *engine, QJSEngine *scriptEngine)
 
 QObject *voiceRecoder_provider(QQmlEngine *engine, QJSEngine *scriptEngine)
 {
+    qInfo() << "voiceRecoder_provider called";
     Q_UNUSED(engine)
     Q_UNUSED(scriptEngine)
 
@@ -111,6 +127,7 @@ QObject *voiceRecoder_provider(QQmlEngine *engine, QJSEngine *scriptEngine)
 
 void VNoteMainManager::initQMLRegister()
 {
+    qInfo() << "Initializing QML registration";
     qmlRegisterSingletonType<VNoteMainManager>("VNote", 1, 0, "VNoteMainManager", mainManager_provider);
     qmlRegisterSingletonType<JsContent>("VNote", 1, 0, "Webobj", jsContent_provider);
     // 菜单项管理
@@ -122,10 +139,12 @@ void VNoteMainManager::initQMLRegister()
     qmlRegisterSingletonType<VoiceRecoderHandler>("VNote", 1, 0, "VoiceRecoderHandler", voiceRecoder_provider);
 
     qmlRegisterType<RecordingCurves>("VNote", 1, 0, "RecordingCurves");
+    qInfo() << "QML registration finished";
 }
 
 void VNoteMainManager::onVNoteFoldersLoaded()
 {
+    qInfo() << "VNote folders loaded";
     // #ifdef IMPORT_OLD_VERSION_DATA
     //     if (m_fNeedUpgradeOldDb) {
     //         //Start upgrade if all components are ready.
@@ -150,6 +169,7 @@ void VNoteMainManager::onVNoteFoldersLoaded()
     //     pFileCleanupWorker->setAutoDelete(true);
     //     pFileCleanupWorker->setObjectName("FileCleanupWorker");
     //     QThreadPool::globalInstance()->start(pFileCleanupWorker);
+    qInfo() << "VNote folders loaded handling finished";
 }
 
 /**
@@ -171,6 +191,7 @@ int VNoteMainManager::loadNotepads()
     int folderCount = 0;
 
     if (folders) {
+        qInfo() << "folders is not nullptr";
         folders->lock.lockForRead();
         folderCount = folders->folders.size();
         qDebug() << "Found" << folderCount << "folders";
@@ -183,6 +204,7 @@ int VNoteMainManager::loadNotepads()
             data.insert(FOLDER_NAME_KEY, folder->name);
             data.insert(FOLDER_COUNT_KEY, QString::number(folder->getNotesCount()));
             data.insert(FOLDER_ICON_KEY, QString::number(folder->defaultIcon));
+            data.insert(FOLDER_ID_KEY, folder->id);
             if (tmpIndexCount != -1) {
                 folder->sortNumber = tmpIndexCount;
             } else {
@@ -205,6 +227,7 @@ int VNoteMainManager::loadNotepads()
         qDebug() << "Folder data sorted and emitted";
     }
 
+    qInfo() << "Notepads loading finished, count:" << folderCount;
     return folderCount;
 }
 
@@ -213,6 +236,7 @@ void VNoteMainManager::vNoteFloderChanged(const int &index)
     qDebug() << "Changing to folder index:" << index;
     VNoteFolder *folder = getFloderByIndex(index);
     if (folder) {
+        qInfo() << "folder is not nullptr";
         m_currentFolderIndex = folder->id;
         qDebug() << "Loading notes for folder ID:" << folder->id;
         if (!loadNotes(folder)) {
@@ -221,11 +245,22 @@ void VNoteMainManager::vNoteFloderChanged(const int &index)
     } else {
         qWarning() << "Invalid folder index:" << index;
     }
+    qInfo() << "Folder change finished";
 }
 
 void VNoteMainManager::vNoteCreateFolder()
 {
     qDebug() << "Creating new folder";
+    // 录音中禁止创建记事本
+    if (VoiceRecoderHandler::instance()->getRecoderType() == VoiceRecoderHandler::Recording) {
+        qWarning() << "Cannot create notebook while recording";
+        return;
+    }
+    // 播放中禁止创建记事本
+    if (OpsStateInterface::instance()->isPlaying()) {
+        qWarning() << "Cannot create notebook while playing";
+        return;
+    }
     VNoteFolder itemData;
     VNoteFolderOper folderOper;
     itemData.name = folderOper.getDefaultFolderName();
@@ -250,11 +285,18 @@ void VNoteMainManager::vNoteCreateFolder()
     } else {
         qWarning() << "Failed to create new folder";
     }
+    qInfo() << "Folder creation finished";
 }
 
 void VNoteMainManager::vNoteDeleteFolder(const int &index)
 {
     qDebug() << "Deleting folder at index:" << index;
+    // 录音或播放中禁止删除
+    if (VoiceRecoderHandler::instance()->getRecoderType() == VoiceRecoderHandler::Recording
+        || OpsStateInterface::instance()->isPlaying()) {
+        qWarning() << "Cannot delete folder while recording or playing";
+        return;
+    }
     VNoteFolder *folder = getFloderByIndex(index);
 
     int listIndex = m_folderSort.indexOf(QString::number(folder->id));
@@ -271,10 +313,12 @@ void VNoteMainManager::vNoteDeleteFolder(const int &index)
     } else {
         qWarning() << "Invalid folder index for deletion:" << index;
     }
+    qInfo() << "Folder deletion finished";
 }
 
 void VNoteMainManager::vNoteChanged(const int &index)
 {
+    qInfo() << "Changing to note index:" << index;
     if (index < 0) {
         qWarning() << "Invalid note index:" << index;
         return;
@@ -282,6 +326,12 @@ void VNoteMainManager::vNoteChanged(const int &index)
     qDebug() << "Changing to note index:" << index;
     m_currentNoteId = index;
     VNoteItem *data = getNoteById(m_currentNoteId);
+    if (!data) {
+        qWarning() << "vNoteChanged resolved to null note, skipping initData";
+        // 清空编辑区避免残留
+        m_richTextManager->initData(nullptr, "");
+        return;
+    }
     m_richTextManager->initData(data, "");
     qDebug() << "Note change completed";
 }
@@ -313,15 +363,18 @@ struct NoteCompare {
  */
 int VNoteMainManager::loadNotes(VNoteFolder *folder)
 {
+    qInfo() << "Loading notes for folder";
     m_currentHasTop = 0;
     m_noteItems.clear();
     int notesCount = -1;
     if (folder) {
+        qInfo() << "folder is not nullptr";
         notesCount = 0;
         VNoteItemOper noteOper;
         VNOTE_ITEMS_MAP *notes = noteOper.getFolderNotes(folder->id);
         QList<QVariantMap> notesDataList;
         if (notes) {
+            qInfo() << "notes is not nullptr";
             notes->lock.lockForRead();
             for (auto it : notes->folderNotes) {
                 QVariantMap data;
@@ -344,26 +397,53 @@ int VNoteMainManager::loadNotes(VNoteFolder *folder)
             std::sort(notesDataList.begin(), notesDataList.end(), NoteCompare());
         }
         if (!notesDataList.isEmpty()) {
+            qInfo() << "notesDataList is not empty";
             m_currentNoteId = notesDataList.first().value("noteId").toInt();
             vNoteChanged(m_currentNoteId);
         } else
             m_currentNoteId = -1;
         emit updateNotes(notesDataList, 0);
     }
+    qInfo() << "Notes loading finished, count:" << notesCount;
     return notesCount;
 }
 
 void VNoteMainManager::insertVoice(const QString &path, qint64 size)
 {
+    qInfo() << "Inserting voice, path:" << path << "size:" << size;
     m_richTextManager->insertVoiceItem(path, size);
+    qInfo() << "Voice insertion finished";
 }
 
 void VNoteMainManager::createNote()
 {
+    qInfo() << "Creating new note";
+    if (!m_searchText.isEmpty()) {
+        qDebug() << "Cannot create note while in search mode";
+        return;
+    }
+    
+    // 录音中禁止创建笔记
+    if (VoiceRecoderHandler::instance()->getRecoderType() == VoiceRecoderHandler::Recording) {
+        qWarning() << "Cannot create note while recording";
+        return;
+    }
+
+    // 播放中禁止创建笔记
+    if (OpsStateInterface::instance()->isPlaying()) {
+        qWarning() << "Cannot create note while playing";
+        return;
+    }
+
     if (m_currentFolderIndex == -1) {
         qWarning() << "Cannot create note: No current folder selected";
         return;
     }
+    VNoteFolder *currentFolder = getFloderById(m_currentFolderIndex);
+    if (currentFolder == nullptr) {
+        qWarning() << "Cannot create note: Current folder not found for ID:" << m_currentFolderIndex;
+        return;
+    }
     qDebug() << "Creating new note in folder ID:" << m_currentFolderIndex;
     VNoteItem tmpNote;
     tmpNote.folderId = m_currentFolderIndex;
@@ -374,6 +454,10 @@ void VNoteMainManager::createNote()
     tmpNote.noteTitle = noteOper.getDefaultNoteName(tmpNote.folderId);
 
     VNoteItem *newNote = noteOper.addNote(tmpNote);
+    if (newNote == nullptr) {
+        qWarning() << "Create note failed: addNote returned null";
+        return;
+    }
     m_currentNoteId = newNote->noteId;
 
     m_noteItems.append(newNote);
@@ -383,14 +467,14 @@ void VNoteMainManager::createNote()
     data.insert(NOTE_TIME_KEY, Utils::convertDateTime(newNote->modifyTime));
     data.insert(NOTE_MODIFY_TIME_KEY, newNote->modifyTime.toString("yyyy-MM-dd hh:mm:ss"));
     data.insert(NOTE_ISTOP_KEY, newNote->isTop);
-    VNoteFolder *folder = getFloderById(newNote->folderId);
-    data.insert(NOTE_FOLDER_ICON_KEY, QString::number(folder->defaultIcon));
-    data.insert(NOTE_FOLDER_NAME_KEY, folder->name);
+    data.insert(NOTE_FOLDER_ICON_KEY, QString::number(currentFolder->defaultIcon));
+    data.insert(NOTE_FOLDER_NAME_KEY, currentFolder->name);
     data.insert(NOTE_ID_KEY, newNote->noteId);
 
     emit addNoteAtHead(data);
     m_richTextManager->initData(newNote, "");
     m_richTextManager->clearJSContent();
+    qInfo() << "Note creation finished";
 }
 
 void VNoteMainManager::saveAs(const QVariantList &index, const QString &path, SaveAsType type)
@@ -410,18 +494,30 @@ void VNoteMainManager::saveAs(const QVariantList &index, const QString &path, Sa
     }
 
     QString defaultName = "";
+    QString urlPath = QUrl(path).path();
+    QFileInfo pathInfo(urlPath);
+    
+    bool isDirectory = pathInfo.isDir() || urlPath.endsWith('/') || QUrl(path).fileName().isEmpty();
+    qDebug() << "Path analysis - isDirectory:" << isDirectory << "pathInfo.isDir():" << pathInfo.isDir();
+    
     switch (type) {
     case Html:
+        qInfo() << "Exporting as HTML";
         exportType = ExportNoteWorker::ExportHtml;
-        defaultName = QUrl(path).fileName();
+        if (!isDirectory && noteDataList.size() == 1) {
+            defaultName = QUrl(path).fileName();
+        }
         break;
     case Text:
+        qInfo() << "Exporting as Text";
         exportType = ExportNoteWorker::ExportText;
-        defaultName = QUrl(path).fileName();
+        if (!isDirectory && noteDataList.size() == 1) {
+            defaultName = QUrl(path).fileName();
+        }
         break;
     case Voice:
+        qInfo() << "Exporting as Voice";
         exportType = ExportNoteWorker::ExportVoice;
-        // 通过qt获取当前时间并转换为字符串
         QDateTime now = QDateTime::currentDateTime();
         QString timeStr = now.toString("yyyyMMddhhmmss");
         defaultName = timeStr + ".mp3";
@@ -434,13 +530,16 @@ void VNoteMainManager::saveAs(const QVariantList &index, const QString &path, Sa
     exportWorker->setAutoDelete(true);
     connect(exportWorker, &ExportNoteWorker::exportFinished, this, &VNoteMainManager::onExportFinished);
     QThreadPool::globalInstance()->start(exportWorker);
+    qInfo() << "SaveAs operation started";
 }
 
 VNoteFolder *VNoteMainManager::getFloderByIndex(const int &index)
 {
+    qInfo() << "Getting folder by index:" << index;
     VNOTE_FOLDERS_MAP *folders = VNoteDataManager::instance()->getNoteFolders();
     int tmpIndex = m_folderSort.at(index).toInt();
     if (folders) {
+        qInfo() << "folders is not nullptr";
         folders->lock.lockForRead();
 
         VNoteFolder *folder = folders->folders.value(tmpIndex);
@@ -452,8 +551,10 @@ VNoteFolder *VNoteMainManager::getFloderByIndex(const int &index)
 
 VNoteFolder *VNoteMainManager::getFloderById(const int &id)
 {
+    qInfo() << "Getting folder by ID:" << id;
     VNOTE_FOLDERS_MAP *folders = VNoteDataManager::instance()->getNoteFolders();
     if (folders) {
+        qInfo() << "folders is not nullptr";
         folders->lock.lockForRead();
 
         QMap<qint64, VNoteFolder *>::iterator itor;
@@ -472,6 +573,7 @@ VNoteFolder *VNoteMainManager::getFloderById(const int &id)
 
 int VNoteMainManager::getFloderIndexById(const int &id)
 {
+    qInfo() << "Getting folder index by ID:" << id;
     VNOTE_FOLDERS_MAP *folders = VNoteDataManager::instance()->getNoteFolders();
     for (int i = 0; i < m_folderSort.size(); i++) {
         int tmpIndex = m_folderSort.at(i).toInt();
@@ -484,6 +586,7 @@ int VNoteMainManager::getFloderIndexById(const int &id)
 
 VNoteItem *VNoteMainManager::getNoteById(const int &id)
 {
+    qInfo() << "Getting note by ID:" << id;
     foreach (auto item, m_noteItems) {
         if (item->noteId == id)
             return item;
@@ -493,6 +596,7 @@ VNoteItem *VNoteMainManager::getNoteById(const int &id)
 
 VNoteItem *VNoteMainManager::deleteNoteById(const int &id)
 {
+    qInfo() << "Deleting note by ID:" << id;
     foreach (auto item, m_noteItems) {
         if (item->noteId == id) {
             m_noteItems.removeOne(item);
@@ -506,6 +610,12 @@ void VNoteMainManager::deleteNote(const QList<int> &index)
 {
     // 删除之前清空JS详情页内容
     qDebug() << "Deleting" << index.size() << "notes";
+    // 录音或播放中禁止删除
+    if (VoiceRecoderHandler::instance()->getRecoderType() == VoiceRecoderHandler::Recording
+        || OpsStateInterface::instance()->isPlaying()) {
+        qWarning() << "Cannot delete note while recording or playing";
+        return;
+    }
     m_richTextManager->clearJSContent();
     QList<VNoteItem *> noteDataList;
     for (int i = 0; i < index.size(); i++) {
@@ -517,14 +627,29 @@ void VNoteMainManager::deleteNote(const QList<int> &index)
     }
 
     if (noteDataList.size()) {
-        qDebug() << "Processing deletion of" << noteDataList.size() << "notes";
+        qWarning() << "Processing deletion of" << noteDataList.size() << "notes";
+        // track deleted count per folder id for UI sync (e.g. search mode)
+        QMap<int, int> folderIdToDeletedCount;
         for (auto noteData : noteDataList) {
+            // 在删除前先保存folderId，避免删除后访问已释放内存
+            int folderId = noteData->folderId;
+            qWarning() << "Deleting note from folder ID:" << folderId;
             VNoteItemOper noteOper(noteData);
             noteOper.deleteNote();
+            folderIdToDeletedCount[folderId] += 1;
         }
+        // Convert QMap to QVariantMap for QML compatibility
+        QVariantMap variantMap;
+        for (auto it = folderIdToDeletedCount.begin(); it != folderIdToDeletedCount.end(); ++it) {
+            variantMap[QString::number(it.key())] = it.value();
+            qWarning() << "Folder ID" << it.key() << "deleted count:" << it.value();
+        }
+        qWarning() << "Emitting notesDeleted signal with" << variantMap.size() << "folders";
+        emit notesDeleted(variantMap);
     } else {
         qWarning() << "No notes to delete";
     }
+    qInfo() << "Note deletion finished";
 }
 
 void VNoteMainManager::moveNotes(const QVariantList &index, const int &folderIndex)
@@ -569,10 +694,12 @@ void VNoteMainManager::moveNotes(const QVariantList &index, const int &folderInd
     folder->maxNoteIdRef() += index.size();
     qDebug() << "Notes moved successfully";
     emit moveFinished(index, srcIndex, folderIndex);
+    qInfo() << "Notes move finished";
 }
 
 void VNoteMainManager::updateTop(const int &id, const bool &top)
 {
+    qInfo() << "Updating top status for note ID:" << id << "to:" << top;
     VNoteItem *note = getNoteById(id);
     if (note == nullptr || note->isTop == top) {
         qWarning() << "Invalid top update operation";
@@ -600,48 +727,64 @@ void VNoteMainManager::updateTop(const int &id, const bool &top)
         return item.value("noteId").toInt() == id;
     });
     emit updateNotes(notesDataList, std::distance(notesDataList.begin(), it));
+    qInfo() << "Top status update finished";
 }
 
 void VNoteMainManager::onExportFinished(int err)
 {
+    qInfo() << "Export finished with error code:" << err;
     Q_UNUSED(err)
     // TODO:提示保存成功
+    qInfo() << "Export finished handling completed";
 }
 
 void VNoteMainManager::onNoteChanged()
 {
+    qInfo() << "Note changed, updating modification time";
     VNoteItem *note = getNoteById(m_currentNoteId);
+    if (!note) {
+        qWarning() << "onNoteChanged: current note not found, id=" << m_currentNoteId << ", skip";
+        return;
+    }
     note->modifyTime = QDateTime::currentDateTime();
     emit updateEditNote(m_currentNoteId, Utils::convertDateTime(note->modifyTime));
+    qInfo() << "Note change handling finished";
 }
 
 void VNoteMainManager::updateSearch()
 {
+    qInfo() << "Updating search";
     if (m_searchText.isEmpty()) {
         qDebug() << "Search text is empty, skipping update";
         return;
     }
     qDebug() << "Updating search with text:" << m_searchText;
     emit updateRichTextSearch(m_searchText);
+    qInfo() << "Search update finished";
 }
 
 void VNoteMainManager::exitWithSave()
 {
+    qInfo() << "Exiting with save";
     if (m_eventloop.isRunning())
         m_eventloop.quit();
+    qInfo() << "Exit with save finished";
 }
 
 bool VNoteMainManager::getTop()
 {
+    qInfo() << "Getting top status:" << m_currentHasTop;
     return m_currentHasTop;
 }
 
 void VNoteMainManager::updateSort(const int &src, const int &dst)
 {
+    qInfo() << "Updating sort, src:" << src << "dst:" << dst;
     QString tmp = m_folderSort.at(src);
     m_folderSort.removeAt(src);
     m_folderSort.insert(dst, tmp);
     setting::instance()->setOption(VNOTE_FOLDER_SORT, m_folderSort.join(","));
+    qInfo() << "Sort update finished";
 }
 
 void VNoteMainManager::renameFolder(const int &index, const QString &name)
@@ -655,6 +798,7 @@ void VNoteMainManager::renameFolder(const int &index, const QString &name)
     } else {
         qWarning() << "Invalid folder rename operation";
     }
+    qInfo() << "Folder rename finished";
 }
 
 void VNoteMainManager::renameNote(const int &index, const QString &newName)
@@ -662,36 +806,72 @@ void VNoteMainManager::renameNote(const int &index, const QString &newName)
     qDebug() << "Renaming note at index" << index << "to:" << newName;
     VNoteItem *item = getNoteById(index);
     if (item && !newName.isEmpty() && newName != item->noteTitle) {
+        qInfo() << "rename note!";
         VNoteItemOper noteOps(item);
-        noteOps.modifyNoteTitle(newName);
-        qDebug() << "Note renamed successfully";
+        if (noteOps.modifyNoteTitle(newName)) {
+            qDebug() << "Note renamed successfully";
+            // 播放中不重新加载列表，避免中断播放状态
+            if (!OpsStateInterface::instance()->isPlaying()) {
+                qDebug() << "Not playing, reloading current folder";
+                VNoteFolder *currentFolder = getFloderById(m_currentFolderIndex);
+                if (currentFolder) {
+                    loadNotes(currentFolder);
+                }
+            } else {
+                qDebug() << "Playing audio, skip reloading to preserve play state";
+                // 更新标题
+                item->noteTitle = newName;
+                emit noteTitleChanged(index, newName);
+            }
+        } else {
+            qWarning() << "Failed to rename note";
+        }
     } else {
         qWarning() << "Invalid note rename operation";
     }
     onNoteChanged();
+    qInfo() << "Note rename finished";
+}
+
+QString VNoteMainManager::getNotePlainTitle(const int &noteId)
+{
+    qDebug() << "Getting plain title for note ID:" << noteId;
+    VNoteItem *item = getNoteById(noteId);
+    if (item) {
+        QString plainTitle = Utils::stripHtmlTags(item->noteTitle);
+        qDebug() << "Plain title for note ID" << noteId << ":" << plainTitle;
+        return plainTitle;
+    } else {
+        qWarning() << "Note not found for ID:" << noteId;
+        return QString();
+    }
 }
 
 void VNoteMainManager::vNoteSearch(const QString &text)
 {
+    qInfo() << "Starting search with text:" << text;
     if (!text.isEmpty()) {
-        if (m_searchText != text) {
-            qDebug() << "Starting new search with text:" << text;
-            m_searchText = text;
-            loadSearchNotes(text);
-        }
+        // 当当前的输入文本和前一次相同的时候，回车也需要触发操作，否则笔记有变更无法及时更新搜索结果
+        qDebug() << "Starting search with text:" << text;
+        m_searchText = text;
+        loadSearchNotes(text);
         updateSearch();
     } else {
         qDebug() << "Search text is empty";
     }
+    qInfo() << "Search operation finished";
 }
 
 void VNoteMainManager::updateNoteWithResult(const QString &result)
 {
+    qInfo() << "Updating note with result";
     m_richTextManager->onUpdateNoteWithResult(getNoteById(m_currentNoteId), result);
+    qInfo() << "Note update with result finished";
 }
 
 int VNoteMainManager::loadSearchNotes(const QString &key)
 {
+    qInfo() << "Loading search notes for key:" << key;
     if (key.isEmpty()) {
         qWarning() << "Empty search key";
         return -1;
@@ -701,6 +881,7 @@ int VNoteMainManager::loadSearchNotes(const QString &key)
     QList<QVariantMap> notesDataList;
     m_noteItems.clear();
     if (noteAll) {
+        qInfo() << "noteAll is not nullptr";
         noteAll->lock.lockForRead();
         for (auto &foldeNotes : noteAll->notes) {
             for (auto note : foldeNotes->folderNotes) {
@@ -723,25 +904,29 @@ int VNoteMainManager::loadSearchNotes(const QString &key)
             qDebug() << "No search results found";
             emit noSearchResult();
         } else {
+            qInfo() << "notesDataList is not empty";
             //TODO:有搜索结果
             emit searchFinished(notesDataList, key);
         }
     }
+    qInfo() << "Search notes loading finished, count:" << notesDataList.size();
     return notesDataList.size();
 }
 
 int VNoteMainManager::loadAudioSource()
 {
+    qInfo() << "Loading audio source";
     return setting::instance()->getOption(VNOTE_AUDIO_SELECT).toInt();
 }
 
 void VNoteMainManager::changeAudioSource(const int &source)
 {
+    qInfo() << "Changing audio source to:" << source;
     setting::instance()->setOption(VNOTE_AUDIO_SELECT, QVariant(source));
     VoiceRecoderHandler::instance()->changeMode(source);
 }
 
-void VNoteMainManager::insertImages(const QStringList &filePaths)
+void VNoteMainManager::insertImages(const QList<QUrl> &filePaths)
 {
     qDebug() << "Inserting" << filePaths.size() << "images";
     int count = 0;
@@ -755,7 +940,8 @@ void VNoteMainManager::insertImages(const QStringList &filePaths)
     QString date = currentDateTime.toString("yyyyMMddhhmmss");
 
     for (auto path : filePaths) {
-        QFileInfo fileInfo(path);
+        QString localPath = path.toLocalFile();
+        QFileInfo fileInfo(localPath);
         QString suffix = fileInfo.suffix();
         if (!(suffix == "jpg" || suffix == "png" || suffix == "bmp")) {
             qWarning() << "Unsupported image format:" << suffix;
@@ -773,10 +959,12 @@ void VNoteMainManager::insertImages(const QStringList &filePaths)
     } else {
         qWarning() << "No valid images to insert";
     }
+    qInfo() << "Image insertion finished";
 }
 
 void VNoteMainManager::checkNoteVoice(const QVariantList &index)
 {
+    qInfo() << "Checking note voice for" << index.size() << "notes";
     foreach (auto id, index) {
         int noteIndex = id.toInt();
         VNoteItem *item = getNoteById(noteIndex);
@@ -786,15 +974,44 @@ void VNoteMainManager::checkNoteVoice(const QVariantList &index)
         }
     }
     ActionManager::instance()->enableAction(ActionManager::NoteSaveVoice, false);
+    qInfo() << "Note voice check finished";
+}
+
+void VNoteMainManager::checkNoteText(const QVariantList &index)
+{
+    qInfo() << "Checking note text for" << index.size() << "notes";
+    foreach (auto id, index) {
+        int noteIndex = id.toInt();
+        VNoteItem *item = getNoteById(noteIndex);
+        if (item && item->haveText()) {
+            ActionManager::instance()->enableAction(ActionManager::NoteSave, true);
+            ActionManager::instance()->enableAction(ActionManager::SaveNoteAsText, true);
+            ActionManager::instance()->enableAction(ActionManager::SaveNoteAsHtml, true);
+            return;
+        }
+    }
+    ActionManager::instance()->enableAction(ActionManager::NoteSave, false);
+    ActionManager::instance()->enableAction(ActionManager::SaveNoteAsText, false);
+    ActionManager::instance()->enableAction(ActionManager::SaveNoteAsHtml, false);
+    qInfo() << "Note text check finished";
 }
 
 void VNoteMainManager::clearSearch()
 {
+    // qInfo() << "Clearing search";
     m_searchText = "";
+    // qInfo() << "Search cleared";
+}
+
+bool VNoteMainManager::isInSearchMode() const
+{
+    qInfo() << "Checking search mode:" << !m_searchText.isEmpty();
+    return !m_searchText.isEmpty();
 }
 
 void VNoteMainManager::preViewShortcut(const QPointF &point)
 {
+    // qInfo() << "Previewing shortcut at point:" << point.x() << "," << point.y();
     QJsonObject shortcutObj;
     QJsonArray jsonGroups;
 
@@ -856,7 +1073,7 @@ void VNoteMainManager::preViewShortcut(const QPointF &point)
                                                          {DApplication::translate("Shortcuts", "Cut"), "Ctrl+X"},
                                                          {DApplication::translate("Shortcuts", "Paste"), "Ctrl+V"},
                                                          {DApplication::translate("Shortcuts", "Undo"), "Ctrl+Z"},
-                                                         {DApplication::translate("Shortcuts", "Redo"), "Ctrl+Y"},
+                                                         {DApplication::translate("Shortcuts", "Redo"), "Ctrl+Shift+Z"},
                                                          {DApplication::translate("Shortcuts", "Delete"), "Delete"},
                                                          };
 
@@ -903,15 +1120,18 @@ void VNoteMainManager::preViewShortcut(const QPointF &point)
 
     QJsonDocument doc(shortcutObj);
 
+    QPoint pos(static_cast<int>(point.x()), static_cast<int>(point.y()));
+    
     QStringList shortcutString;
     QString param1 = "-j=" + QString(doc.toJson().data());
-    QString param2 = "-p=" + QString::number(point.x()) + "," + QString::number(point.y());
+    QString param2 = "-p=" + QString::number(pos.x()) + "," + QString::number(pos.y());
     shortcutString << param1 << param2;
 
     QProcess *shortcutViewProcess = new QProcess(this);
     shortcutViewProcess->startDetached("deepin-shortcut-viewer", shortcutString);
 
     connect(shortcutViewProcess, SIGNAL(finished(int)), shortcutViewProcess, SLOT(deleteLater()));
+    // qInfo() << "Shortcut preview finished";
 }
 
 void VNoteMainManager::showPrivacy()
@@ -920,7 +1140,7 @@ void VNoteMainManager::showPrivacy()
     QString url = "";
     QLocale locale;
     QLocale::Country country = locale.country();
-    bool isCommunityEdition = DSysInfo::isCommunityEdition();
+    bool isCommunityEdition = Utils::isCommunityEdition();
     if (country == QLocale::China) {
         if (isCommunityEdition) {
             url = "https://www.deepin.org/zh/agreement/privacy/";
@@ -936,11 +1156,14 @@ void VNoteMainManager::showPrivacy()
     }
     qDebug() << "Opening privacy URL:" << url;
     QDesktopServices::openUrl(url);
+    qInfo() << "Privacy policy shown";
 }
 
 void VNoteMainManager::resumeVoicePlayer()
 {
+    qInfo() << "Resuming voice player";
     JsContent::instance()->jsCallPlayVoice("", true);
+    qInfo() << "Voice player resumed";
 }
 
 void VNoteMainManager::forceExit(bool needWait)
@@ -955,11 +1178,44 @@ void VNoteMainManager::forceExit(bool needWait)
     VTextSpeechAndTrManager::instance()->onStopTextToSpeech();
     QApplication::exit(0);
     _Exit(0);
+    qInfo() << "Force exit completed";
 }
 
 bool VNoteMainManager::isVoiceToText()
 {
+    qInfo() << "Checking voice to text status";
     bool result = OpsStateInterface::instance()->isVoice2Text();
     qDebug() << "Voice to text status:" << result;
     return result;
 }
+
+QString VNoteMainManager::getSavedTextPath()
+{
+    qInfo() << "Getting saved text path";
+    QString savedPath = setting::instance()->getOption(VNOTE_EXPORT_TEXT_PATH_KEY).toString();
+    qDebug() << "Retrieved saved path (unified):" << savedPath;
+    return savedPath;
+}
+
+QString VNoteMainManager::getSavedVoicePath()
+{
+    qInfo() << "Getting saved voice path";
+    QString savedPath = setting::instance()->getOption(VNOTE_EXPORT_TEXT_PATH_KEY).toString();
+    qDebug() << "Retrieved saved path (unified):" << savedPath;
+    return savedPath;
+}
+
+void VNoteMainManager::saveUserSelectedPath(const QString &path, const SaveAsType type)
+{
+    qDebug() << "Saving user selected path:" << path << "for type:" << type;
+    
+    QString dirPath = path;
+    QFileInfo pathInfo(path);
+    if (pathInfo.isFile() || (!pathInfo.exists() && !path.endsWith('/') && path.contains('.'))) {
+        dirPath = pathInfo.absolutePath();
+        qDebug() << "Extracted directory path:" << dirPath << "from file path:" << path;
+    }
+    
+    setting::instance()->setOption(VNOTE_EXPORT_TEXT_PATH_KEY, dirPath);
+    qDebug() << "Saved unified export directory to settings:" << dirPath;
+}
