@@ -84,6 +84,7 @@ signals:
     void playVoiceProgressChange(qint64 progressMs);
     void viewPictrue(const QString &imagePath);
     void createNote();
+    void saveAudio();
     /**
      * @brief 编辑区内容加载完成信号
      */
@@ -116,6 +117,7 @@ public slots:
     void jsCallPaste(bool isVoicePaste = false); //web前端调用后端，编辑区粘贴功能
     void jsCallViewPicture(const QString &imagePath); //web前端调用后端，进行图片预览
     void jsCallCreateNote(); //web前端调用后端，新建笔记
+    void jsCallSaveAudio(); //web前端调用后端，保存录音
     void jsCallSetClipData(const QString &text, const QString &html); //web前端调用后端，设置剪切板内容
     QString jsCallGetTranslation(); //web前端调用后端，获取翻译
     QString jsCallDivTextTranslation(); // web前端调用后端，获取动态组件翻译
