@@ -18,10 +18,19 @@
 #include <QBuffer>
 #include <QFileInfo>
 #include <QProcess>
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+#include <QRegularExpression>
+#else
+#include <QRegExp>
+#endif
+#include <QTextDocument>
 #include <QTextDocumentFragment>
+#include <QDBusInterface>
+#include <QDBusConnection>
 
 Utils::Utils()
 {
+    qInfo() << "Utils constructor called";
 }
 
 /**
@@ -31,6 +40,7 @@ Utils::Utils()
  */
 QString Utils::convertDateTime(const QDateTime &dateTime)
 {
+    qInfo() << "Converting date time:" << dateTime.toString();
     QDate currDateTime = QDate::currentDate();
     QDate folerDate = dateTime.date();
     QString disptime;
@@ -39,12 +49,14 @@ QString Utils::convertDateTime(const QDateTime &dateTime)
     qDebug() << "Converting date time:" << dateTime.toString() << "offset days:" << offset;
     
     if (0 == offset) {
+        qInfo() << "Offset is 0";
         qint64 offsetSec = dateTime.secsTo(QDateTime::currentDateTime());
         if (offsetSec < 3600) {
             offsetSec /= 60;
             if (offsetSec <= 1) {
                 disptime = DApplication::translate("Utils", "1 min ago");
             } else {
+                qInfo() << "Offset is greater than 1 minute";
                 disptime = DApplication::translate("Utils", "%1 mins ago").arg(offsetSec);
             }
             qDebug() << "Time is" << offsetSec << "minutes ago";
@@ -85,6 +97,7 @@ QPixmap Utils::renderSVG(const QString &filePath, const QSize &size, DApplicatio
     reader.setFileName(filePath);
 
     if (reader.canRead()) {
+        qInfo() << "SVG can read";
         // const qreal ratio = qApp->devicePixelRatio();
         const qreal ratio = pApp->devicePixelRatio();
         reader.setScaledSize(size * ratio);
@@ -132,9 +145,11 @@ QPixmap Utils::loadSVG(const QString &fileName, bool fCommon)
     QPixmap pixmap;
 
     if (!qFuzzyCompare(ratio, devicePixelRatio)) {
+        qInfo() << "Device pixel ratio is not the same";
         QImageReader reader;
         reader.setFileName(qt_findAtNxFile(iconPath, devicePixelRatio, &ratio));
         if (reader.canRead()) {
+            qInfo() << "SVG can read";
             reader.setScaledSize(reader.size() * (devicePixelRatio / ratio));
             pixmap = QPixmap::fromImage(reader.read());
             pixmap.setDevicePixelRatio(devicePixelRatio);
@@ -143,6 +158,7 @@ QPixmap Utils::loadSVG(const QString &fileName, bool fCommon)
             qWarning() << "Failed to read SVG file:" << iconPath;
         }
     } else {
+        qInfo() << "Device pixel ratio is the same";
         pixmap.load(iconPath);
         qDebug() << "SVG loaded with default ratio";
     }
@@ -166,10 +182,11 @@ int Utils::highTextEdit(QTextDocument *textDoc, const QString &searchKey,
     int findCount = 0;
     int len = searchKey.length();
     if (undo == true) {
+        qInfo() << "Undoing previous operation";
         textDoc->undo();
-        qDebug() << "Undid previous operation";
     }
     if (len != 0) {
+        qInfo() << "Searching for text";
         QTextCursor highlightCursor(textDoc);
         QTextCursor cursor(textDoc);
 
@@ -230,10 +247,12 @@ void Utils::documentToBlock(VNoteBlock *block, const QTextDocument *doc)
     qDebug() << "Converting document to block";
     
     if (block != nullptr) {
+        qInfo() << "Block is not nullptr";
         block->blockText = "";
     }
 
     if (doc != nullptr) {
+        qInfo() << "Doc is not nullptr";
         QTextBlock currentBlock = doc->begin();
         QTextBlock::iterator it;
         while (true) {
@@ -300,6 +319,7 @@ void Utils::setDefaultColor(QTextDocument *srcDoc, const QColor &color)
  */
 void Utils::setTitleBarTabFocus(QKeyEvent *event)
 {
+    // qInfo() << "Setting title bar tab focus";
     // VNoteApplication *app = dynamic_cast<VNoteApplication *>(qGuiApp);
     // if (app) {
     //     VNoteMainWindow *wnd = app->mainWindow();
@@ -378,16 +398,20 @@ QString Utils::filteredFileName(QString fileName, const QString &defaultName)
 {
     qDebug() << "Filtering file name:" << fileName << "default:" << defaultName;
     //使用正则表达式除去不符合规范的字符并清理文件名两端的空白字符，中间的空白字符不做处理
-    // QString name = fileName.replace(QRegExp("[\"\'\\[\\]\\\\/:|<>+=;,?*]"), "").trimmed();
-    // if (name.isEmpty()) {
-    //     return defaultName;
-    // }
-    // return name;
-    return QString();
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+    QString name = fileName.replace(QRegularExpression("[\"\'\\[\\]\\\\/:|<>+=;,?*]"), "").trimmed();
+#else
+    QString name = fileName.replace(QRegExp("[\"\'\\[\\]\\\\/:|<>+=;,?*]"), "").trimmed();
+#endif
+    if (name.isEmpty()) {
+        return defaultName;
+    }
+    return name;
 }
 
 bool Utils::isWayland()
 {
+    // qInfo() << "Checking if platform is Wayland";
     return false;
     // return qApp->platformName() == "dwayland" || qApp->property("_d_isDwayland").toBool();
 }
@@ -400,7 +424,125 @@ QString Utils::createRichText(const QString &title, const QString &key)
     return newText;
 }
 
+QString Utils::stripHtmlTags(const QString &htmlText)
+{
+    qDebug() << "Stripping HTML tags from text:" << htmlText;
+    QTextDocument doc;
+    doc.setHtml(htmlText);
+    QString plainText = doc.toPlainText();
+    qDebug() << "Converted to plain text:" << plainText;
+    return plainText;
+}
+
 bool Utils::inLinglongEnv()
 {
+    // qInfo() << "Checking if in Linglong environment";
     return !qgetenv("LINGLONG_APPID").isEmpty();
 }
+
+bool Utils::checkOsBuildValid(const QString& str)
+{
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+    static QRegularExpression regex("^[1-9A-Z][1-9A-Z][0-9A-Z][1-9A-Z][1-9A-Z](\\.\\w+)*$");
+    return regex.match(str).hasMatch();
+#else
+    static QRegExp regex("^[1-9A-Z][1-9A-Z][0-9A-Z][1-9A-Z][1-9A-Z](\\.\\w+)*$");
+    return regex.exactMatch(str);
+#endif
+}
+
+DSysInfo::UosEdition Utils::uosEditionType()
+{
+    static DSysInfo::UosEdition cachedEdition = DSysInfo::UosEdition::UosEditionUnknown;
+    static bool hasQueried = false;
+    if (hasQueried)
+        return cachedEdition;
+
+    QDBusInterface interface("org.deepin.dde.SystemInfo1",
+                            "/org/deepin/dde/SystemInfo1",
+                            "org.deepin.dde.SystemInfo1",
+                            QDBusConnection::sessionBus());
+
+    if(!interface.isValid()) {
+        hasQueried = true;
+        return cachedEdition;
+    }
+
+    QVariant osBuild = interface.property("OsBuild");
+    if(!osBuild.isValid()) {
+        hasQueried = true;
+        return cachedEdition;
+    }
+
+    const QString buildType = osBuild.toString();
+    if(buildType.isEmpty()) {
+        hasQueried = true;
+        return cachedEdition;
+    }
+
+    const QStringList parts = buildType.split(".");
+    if(parts.size() != 3) {
+        hasQueried = true;
+        return cachedEdition;
+    }
+
+    cachedEdition = parseOsBuildType(parts[0]);
+    hasQueried = true;
+    return cachedEdition;
+}
+
+DSysInfo::UosEdition Utils::parseOsBuildType(const QString & osBuild)
+{
+    if (!checkOsBuildValid(osBuild)) {
+        return DSysInfo::UosEdition::UosEditionUnknown;
+    }
+
+    int uosType = osBuild[1].digitValue();
+    int uosEditType = osBuild[3].digitValue();
+
+    if(uosType == 1) {
+        switch (uosEditType) {
+        case 1:
+            return DSysInfo::UosEdition::UosProfessional;
+        case 2:
+        case 7:
+            return DSysInfo::UosEdition::UosHome;
+        case 3:
+            return DSysInfo::UosEdition::UosCommunity;
+        case 4:
+        case 9:
+            return DSysInfo::UosEdition::UosMilitary;
+        case 5:
+            return DSysInfo::UosEdition::UosDeviceEdition;
+        case 6:
+            return DSysInfo::UosEdition::UosEducation;
+        default:
+            break;
+        }
+    } else if(uosType == 2) {
+        switch (uosEditType) {
+        case 1:
+            return DSysInfo::UosEdition::UosEnterprise;
+        case 2:
+            return DSysInfo::UosEdition::UosEnterpriseC;
+        case 3:
+            return DSysInfo::UosEdition::UosEuler;
+        case 4:
+        case 9:
+            return DSysInfo::UosEdition::UosMilitaryS;
+        case 5:
+            return DSysInfo::UosEdition::UosDeviceEdition;
+        default:
+            break;
+        }
+    } else if (uosType == 3) {
+        return DSysInfo::UosEdition::UosEnterprise;
+    }
+
+    return DSysInfo::UosEdition::UosEditionUnknown;
+}
+
+bool Utils::isCommunityEdition()
+{
+    return uosEditionType() == DSysInfo::UosEdition::UosCommunity;
+}
