@@ -5,27 +5,48 @@
 
 #include <QTimer>
 #include <QEventLoop>
+#include <QDebug>
 
 WebRichTextManager::WebRichTextManager(QObject *parent)
 : QObject(parent)
 {
+    qInfo() << "WebRichTextManager constructor called";
     initUpdateTimer();
     initConnect();
+    qInfo() << "WebRichTextManager constructor finished";
 }
 
 void WebRichTextManager::initData(VNoteItem *data, const QString reg, bool focus)
 {
+    qInfo() << "Initializing data for note ID:" << (data ? data->noteId : -1);
     //重置鼠标点击位置
     m_mouseClickPos = QPoint(-1, -1);
     m_setFocus = focus;
+    // 若数据为空，清空页面并返回，避免后续异步回调空指针
+    if (!data) {
+        qWarning() << "initData called with null data, clearing JS content";
+        m_noteData = nullptr;
+        if (m_updateTimer) m_updateTimer->stop();
+        clearJSContent();
+        return;
+    }
+    // 保存当前数据供 onLoadFinsh 以及异步回调使用
+    m_noteData = data;
     //富文本设置异步操作，解决笔记列表不实时刷新
-    QTimer::singleShot(50, this, [ = ] {
-        setData(data, reg);
+    QTimer::singleShot(50, this, [this, reg] {
+        // 使用成员 m_noteData 避免捕获过期指针
+        if (!m_noteData) {
+            qWarning() << "Deferred setData skipped due to null m_noteData";
+            return;
+        }
+        setData(m_noteData, reg);
     });
+    qInfo() << "Data initialization finished";
 }
 
 void WebRichTextManager::initConnect()
 {
+    qInfo() << "Initializing connections";
     connect(JsContent::instance(), &JsContent::textChange, this, [=](){
         m_textChange = true;
         emit noteTextChanged();
@@ -34,11 +55,17 @@ void WebRichTextManager::initConnect()
     connect(JsContent::instance(), &JsContent::scrollTopChange, this, [=](bool isTop){
         emit scrollChange(isTop);
     });
+    qInfo() << "Connections initialized";
 }
 
 void WebRichTextManager::setData(VNoteItem *data, const QString reg)
 {
     qDebug() << "Setting rich text data";
+    if (!data) {
+        qWarning() << "setData called with null data, skip";
+        return;
+    }
+    m_noteData = data;
     m_updateTimer->stop();
     //设置富文本内容
     if (data->htmlCode.isEmpty()) {
@@ -50,25 +77,34 @@ void WebRichTextManager::setData(VNoteItem *data, const QString reg)
     }
     m_updateTimer->start();
     emit updateSearch();
+    qInfo() << "Rich text data setting finished";
 }
 
 void WebRichTextManager::initUpdateTimer()
 {
+    qInfo() << "Initializing update timer";
     m_updateTimer = new QTimer(this);
     m_updateTimer->setInterval(1000);
     connect(m_updateTimer, &QTimer::timeout, this, &WebRichTextManager::updateNote);
+    qInfo() << "Update timer initialized";
 }
 
 void WebRichTextManager::updateNote()
 {
+    qInfo() << "Updating note, text change flag:" << m_textChange;
     if (m_textChange) {
         emit needUpdateNote();
     }
+    qInfo() << "Note update finished";
 }
 
 void WebRichTextManager::onUpdateNoteWithResult(VNoteItem *data, const QString &result)
 {
     qDebug() << "Updating note with result";
+    if (!data) {
+        qWarning() << "onUpdateNoteWithResult called with null data, skip";
+        return;
+    }
     data->htmlCode = result;
     VNoteItemOper noteOps(data);
     if (!noteOps.updateNote()) {
@@ -78,6 +114,7 @@ void WebRichTextManager::onUpdateNoteWithResult(VNoteItem *data, const QString &
     }
     m_textChange = false;
     emit finishedUpdateNote();
+    qInfo() << "Note update with result finished";
 }
 
 void WebRichTextManager::insertVoiceItem(const QString &voicePath, qint64 voiceSize)
@@ -115,6 +152,7 @@ void WebRichTextManager::onLoadFinsh()
         }
     }
     m_loadFinshSign = true;
+    qInfo() << "Web communication establishment handling finished";
 }
 
 void WebRichTextManager::clearJSContent()
@@ -133,4 +171,5 @@ void WebRichTextManager::clearJSContent()
 
 void WebRichTextManager::onSetDataFinsh()
 {
+    qInfo() << "Set data finished";
 }
