@@ -16,6 +16,7 @@
 #include <QDateTime>
 #include <QFile>
 #include <QFileInfo>
+#include <QDebug>
 
 /**
  * @brief ExportNoteWorker::ExportNoteWorker
@@ -34,6 +35,9 @@ ExportNoteWorker::ExportNoteWorker(const QString &dirPath, ExportType exportType
     //笔记列表
     , m_noteList(noteList)
 {
+    qInfo() << "ExportNoteWorker constructor called with export type:" << exportType 
+            << "path:" << dirPath << "default name:" << defaultName 
+            << "note count:" << noteList.size();
 }
 
 /**
@@ -46,25 +50,32 @@ void ExportNoteWorker::run()
     ExportError error = checkPath();
 
     if (ExportOK == error) {
+        QString dirPath = m_exportPath;
+        QFileInfo pathInfo(m_exportPath);
+        if (pathInfo.isFile() || (!pathInfo.exists() && !m_exportPath.endsWith('/'))) {
+            dirPath = pathInfo.absolutePath();
+        }
+        
         if (ExportText == m_exportType) {
             qDebug() << "Starting text export";
             error = exportText();
-            setting::instance()->setOption(VNOTE_EXPORT_TEXT_PATH_KEY, m_exportPath);
         } else if (ExportVoice == m_exportType) {
             qDebug() << "Starting voice export";
             error = exportAllVoice();
-            setting::instance()->setOption(VNOTE_EXPORT_VOICE_PATH_KEY, m_exportPath);
         } else if (ExportHtml == m_exportType) {
             qDebug() << "Starting HTML export";
             error = exportAsHtml();
-            setting::instance()->setOption(VNOTE_EXPORT_TEXT_PATH_KEY, m_exportPath);
         }
+        
+        setting::instance()->setOption(VNOTE_EXPORT_TEXT_PATH_KEY, dirPath);
+        qDebug() << "Saved unified export directory to settings:" << dirPath;
     } else {
         qCritical() << "Export path check failed - Error:" << error;
     }
 
     qInfo() << "Export operation completed - Result:" << error;
     emit exportFinished(error);
+    qInfo() << "Export operation finished signal emitted";
 }
 
 /**
@@ -79,6 +90,7 @@ ExportNoteWorker::ExportError ExportNoteWorker::checkPath()
     QFileInfo exportDir(m_exportPath);
 
     if (!m_exportPath.isEmpty()) {
+        qInfo() << "m_exportPath is not empty";
         QFileInfo dir(exportDir.absolutePath());
         if (!dir.exists()) {
             qDebug() << "Creating export directory:" << m_exportPath;
@@ -95,6 +107,7 @@ ExportNoteWorker::ExportError ExportNoteWorker::checkPath()
         error = PathInvalid;
     }
 
+    qInfo() << "Export path check finished, result:" << error;
     return error;
 }
 
@@ -105,9 +118,11 @@ ExportNoteWorker::ExportError ExportNoteWorker::checkPath()
  */
 ExportNoteWorker::ExportError ExportNoteWorker::exportText()
 {
+    qInfo() << "Exporting text, note count:" << m_noteList.size();
     ExportError error = ExportOK;
     //存在note
     if (m_noteList.size()) {
+        qInfo() << "m_noteList is not empty";
         for (auto noteData : m_noteList) {
             if (!noteData->haveText()) {
                 qDebug() << "Skipping note without text content";
@@ -115,7 +130,8 @@ ExportNoteWorker::ExportError ExportNoteWorker::exportText()
             }
             QString filePath = "";
             //没有指定保存名称，则设置默认名称为笔记标题
-            if (m_exportName.isEmpty()) {
+            QFileInfo pathInfo(m_exportPath);
+            if (pathInfo.isDir() || m_exportPath.endsWith('/') || m_exportName.isEmpty()) {
                 QString baseFileName = m_exportPath + "/" + Utils::filteredFileName(noteData->noteTitle, "note");
                 QString fileSuffix = ".txt";
                 filePath = getExportFileName(baseFileName, fileSuffix);
@@ -149,6 +165,7 @@ ExportNoteWorker::ExportError ExportNoteWorker::exportText()
         qWarning() << "No notes to export";
         error = NoteInvalid;
     }
+    qInfo() << "Text export finished, result:" << error;
     return error;
 }
 
@@ -159,9 +176,11 @@ ExportNoteWorker::ExportError ExportNoteWorker::exportText()
  */
 ExportNoteWorker::ExportError ExportNoteWorker::exportAllVoice()
 {
+    qInfo() << "Exporting all voice, note count:" << m_noteList.size();
     ExportError error = ExportOK;
     //存在note
     if (m_noteList.size()) {
+        qInfo() << "m_noteList is not empty";
         for (auto noteData : m_noteList) {
             if (!noteData->haveVoice()) {
                 qDebug() << "Skipping note without voice content";
@@ -195,6 +214,7 @@ ExportNoteWorker::ExportError ExportNoteWorker::exportAllVoice()
         error = NoteInvalid;
     }
 
+    qInfo() << "All voice export finished, result:" << error;
     return error;
 }
 
@@ -206,12 +226,15 @@ ExportNoteWorker::ExportError ExportNoteWorker::exportAllVoice()
  */
 ExportNoteWorker::ExportError ExportNoteWorker::exportOneVoice(const QString &json)
 {
+    qInfo() << "Exporting one voice from JSON";
     VNVoiceBlock voiceBlock;
     MetaDataParser dataParser;
     //解析json数据
     if (dataParser.parse(json, &voiceBlock)) {
+        qInfo() << "Voice export from JSON success";
         return exportOneVoice(&voiceBlock);
     }
+    qInfo() << "Voice export from JSON failed, invalid data";
     return NoteInvalid;
 }
 
@@ -226,6 +249,7 @@ ExportNoteWorker::ExportError ExportNoteWorker::exportOneVoice(VNoteBlock *noteb
     ExportError error = ExportOK;
 
     if (noteblock && noteblock->blockType == VNoteBlock::Voice) {
+        qInfo() << "noteblock is not nullptr and noteblock->blockType is Voice";
         QString baseFileName = m_exportPath + "/" + noteblock->ptrVoice->voiceTitle;
         QString fileSuffix = ".mp3";
         QString dstFileName = getExportFileName(baseFileName, fileSuffix);
@@ -241,6 +265,7 @@ ExportNoteWorker::ExportError ExportNoteWorker::exportOneVoice(VNoteBlock *noteb
         error = NoteInvalid;
     }
 
+    qInfo() << "Voice block export finished, result:" << error;
     return error;
 }
 
@@ -251,6 +276,7 @@ ExportNoteWorker::ExportError ExportNoteWorker::exportOneVoice(VNoteBlock *noteb
  */
 ExportNoteWorker::ExportError ExportNoteWorker::exportAsHtml()
 {
+    qInfo() << "Exporting as HTML, note count:" << m_noteList.size();
     ExportError error = ExportOK;
     for (auto note : m_noteList) {
         if (!note->haveText()) {
@@ -259,11 +285,12 @@ ExportNoteWorker::ExportError ExportNoteWorker::exportAsHtml()
         }
         QString filePath = "";
         //没有指定保存名称，则设置默认名称为笔记标题
-        if (m_exportName.isEmpty()) {
+        QFileInfo pathInfo(m_exportPath);
+        if (pathInfo.isDir() || m_exportPath.endsWith('/') || m_exportName.isEmpty()) {
             QString baseFileName = m_exportPath + "/" + Utils::filteredFileName(note->noteTitle, "note");
             QString fileSuffix = ".html";
             filePath = getExportFileName(baseFileName, fileSuffix);
-        } else {
+        } else {            
             filePath = m_exportPath;
         }
         QFile out(filePath);
@@ -275,7 +302,9 @@ ExportNoteWorker::ExportError ExportNoteWorker::exportAsHtml()
             qWarning() << "Failed to write HTML content to file:" << filePath;
             return Savefailed; //保存失败
         }
+        out.close();  
     }
+    qInfo() << "HTML export finished, result:" << error;
     return error;
 }
 
@@ -291,5 +320,6 @@ QString ExportNoteWorker::getExportFileName(const QString &baseName, const QStri
         }
         filePath = baseName + "(" + QString::number(count++) + ")" + fileSuffix;
     }
+    qInfo() << "Generated unique filename:" << filePath;
     return filePath;
 }
