@@ -4,17 +4,19 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "vnmainwnddelayinittask.h"
-#include "views/vnotemainwindow.h"
+// #include "views/vnotemainwindow.h"
+#include <QDebug>
 
 /**
  * @brief VNMainWndDelayInitTask::VNMainWndDelayInitTask
  * @param pMainWnd 主窗口
  * @param parent
  */
-VNMainWndDelayInitTask::VNMainWndDelayInitTask(VNoteMainWindow *pMainWnd, QObject *parent)
+VNMainWndDelayInitTask::VNMainWndDelayInitTask(/*VNoteMainWindow *pMainWnd, */ QObject *parent)
     : VNTask(parent)
-    , m_pMainWnd(pMainWnd)
+    // , m_pMainWnd(pMainWnd)
 {
+    // qInfo() << "VNMainWndDelayInitTask constructor called";
 }
 
 /**
@@ -22,8 +24,11 @@ VNMainWndDelayInitTask::VNMainWndDelayInitTask(VNoteMainWindow *pMainWnd, QObjec
  */
 void VNMainWndDelayInitTask::run()
 {
+    // qInfo() << "Running VNMainWndDelayInitTask";
     if (nullptr != m_pMainWnd) {
+        // qInfo() << "m_pMainWnd is not nullptr";
         //Delay initialize work
-        m_pMainWnd->initDelayWork();
+        // m_pMainWnd->initDelayWork();
     }
+    // qInfo() << "VNMainWndDelayInitTask run finished";
 }
